@@ -1,6 +1,9 @@
 package Test::Able::Runner::Role::Meta::Class;
-our $VERSION = '1.001';
+{
+  $Test::Able::Runner::Role::Meta::Class::VERSION = '1.002';
+}
 use Moose::Role;
+use Class::Load;
 
 =head1 NAME
 
@@ -8,7 +11,7 @@ Test::Able::Runner::Role::Meta::Class - metaclass role for test runners
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 DESCRIPTION
 
@@ -119,7 +122,7 @@ sub build_test_objects {
     PACKAGE: for my $test_class ($meta->name, $meta->test_classes) {
 
         # Attempt to load the classes
-        unless (Class::MOP::load_class($test_class)) {
+        unless (Class::Load::load_class($test_class)) {
             warn $@ if $@;
             warn "FAILED TO LOAD $test_class. Skipping.";
             next PACKAGE;
@@ -171,4 +174,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
